@@ -1,14 +1,17 @@
 import abc
 from sqlite3 import Connection
 from typing import List
+
+from tileset_analyzer.entities.layer_level_size import LayerLevelSize
 from tileset_analyzer.entities.level_count import LevelCount
 from tileset_analyzer.entities.level_size import LevelSize
 from tileset_analyzer.entities.tileset_analysis_result import TilesetAnalysisResult
+from tileset_analyzer.entities.tileset_info import TilesetInfo
 
 
 class TileSource(abc.ABC):
     @abc.abstractmethod
-    def __init__(self, src_path: str):
+    def __init__(self, src_path: str, scheme: str):
         pass
 
     @abc.abstractmethod
@@ -55,6 +58,14 @@ class TileSource(abc.ABC):
     def tiles_size_agg_99p_by_z(self) -> List[LevelSize]:
         pass
 
+    @abc.abstractmethod
+    def tileset_info(self) -> TilesetInfo:
+        pass
+
+    @abc.abstractmethod
+    def tiles_size_agg_sum_by_z_layer(self) -> List[LayerLevelSize]:
+        pass
+
     @abc.abstractmethod
     def analyze(self) -> TilesetAnalysisResult:
         pass
