@@ -5,11 +5,11 @@ from tileset_analyzer.data_source.mbtiles.mbtiles_source import MBTileSource
 
 class TilesetSourceFactory:
     @staticmethod
-    def get_tileset_source(src_path: str):
+    def get_tileset_source(src_path: str, scheme: str):
         try:
             if src_path.endswith('mbtiles'):
-                return MBTileSource(src_path)
+                return MBTileSource(src_path, scheme)
             
-            raise AssertionError("Car type is not valid.")
+            raise AssertionError("Tileset Type is not valid.")
         except AssertionError as e:
             print(e)
